import React from 'react';
import useScript from 'react-script-hook';

/* global mapkit */
var MapkitContext =
/*#__PURE__*/
React.createContext({
  isInProvider: false,
  mapkit: undefined
});
var MapkitProvider = function MapkitProvider(_ref) {
  var tokenOrCallback = _ref.tokenOrCallback,
      children = _ref.children;
  var existingContext = React.useContext(MapkitContext);

  var _useScript = useScript({
    src: 'https://cdn.apple-mapkit.com/mk/5.x.x/mapkit.js'
  }),
      scriptLoading = _useScript[0];

  var _React$useState = React.useState({
    mapkit: existingContext.mapkit,
    isInProvider: true
  }),
      context = _React$useState[0],
      setContext = _React$useState[1];

  React.useEffect(function () {
    if (!existingContext.isInProvider) {
      if (!scriptLoading) {
        var isCallback = tokenOrCallback.includes('/');
        mapkit.init({
          authorizationCallback: function authorizationCallback(done) {
            if (isCallback) {
              fetch(tokenOrCallback).then(function (res) {
                return res.text();
              }).then(done);
            } else {
              done(tokenOrCallback);
            }
          }
        });
        setContext({
          mapkit: mapkit,
          isInProvider: true
        });
      }
    }
  }, [existingContext.isInProvider, scriptLoading, tokenOrCallback]);
  return React.createElement(MapkitContext.Provider, {
    value: context,
    children: children
  });
};

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var useMap = function useMap() {
  var _React$useContext = React.useContext(MapkitContext),
      mapkit = _React$useContext.mapkit;

  var map = React.useRef();
  var mapCallRef = React.useCallback(function (node) {
    if (mapkit && node !== null) {
      map.current = new mapkit.Map(node);
    }
  }, [mapkit]); // Clean up the map on unmount

  React.useEffect(function () {
    return function () {
      if (map.current) {
        map.current.destroy();
      }
    };
  }, []);
  return {
    map: map.current,
    mapRef: mapCallRef
  };
};

var MapBox = function MapBox(_ref) {
  var children = _ref.children;

  var _useMap = useMap(),
      mapRef = _useMap.mapRef,
      loadMap = _useMap.loadMap;

  return React.createElement(React.Fragment, null, React.createElement("button", {
    onClick: loadMap
  }), React.createElement("div", {
    ref: mapRef,
    style: {
      width: '100%',
      height: '100%'
    },
    children: children
  }));
};
var Map = function Map(_ref2) {
  var tokenOrCallback = _ref2.tokenOrCallback,
      props = _objectWithoutPropertiesLoose(_ref2, ["tokenOrCallback"]);

  var context = React.useContext(MapkitContext);

  if (context.isInProvider) {
    return React.createElement(MapBox, Object.assign({}, props));
  } // No Provider


  if (!tokenOrCallback) {
    throw new Error('`tokenOrCallback` is required. Either add it to this `Map` component or to a `MapkitProvider` parent of this component.');
  }

  return React.createElement(MapkitProvider, {
    tokenOrCallback: tokenOrCallback
  }, React.createElement(MapBox, Object.assign({}, props)));
};

var Marker = function Marker() {
  // const context = React.useContext(MapkitContext)
  return React.createElement("div", null, "Marker!");
};

// export * from './useMap'

export { Map, MapBox, MapkitContext, MapkitProvider, Marker, useMap };
//# sourceMappingURL=mapkit.esm.js.map
